/*
 Copyright (C) 2024 3NSoft Inc.

 This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

import { defineStore } from 'pinia';
import type { ProcessStoreState, ProcessActions, ProcessType } from './types';

const upsertProcess: ProcessActions['upsertProcess'] = function (
  appId, processInfo
) {
  const procId = procIdFor(appId, processInfo.procType);
  this.processes[procId] = processInfo;
};

const delProcess: ProcessActions['delProcess'] = function (appId, procType) {
  const procId = procIdFor(appId, procType);
  delete this.processes[procId];
};

function procIdFor(appId: string, procType: ProcessType): string {
  return `${appId}/${procType}`;
}

const actions: ProcessActions = {
  upsertProcess,
  delProcess,
};

export const processStore = defineStore({
  id: 'process',
  state: (): ProcessStoreState => ({
    processes: {},
  }),
  actions,
});
